@@ -186,9 +186,22 @@ sub quote ( $self, $var, $type = undef ) {
 sub quote_id ( $self, $id ) {
     utf8::encode $id if utf8::is_utf8 $id;
 
-    $id =~ s/"/""/smg;
+    if ( index( $id, q[.] ) != -1 ) {
+        my @id = split /[.]/sm, $id;
 
-    return qq["$id"];
+        for my $s (@id) {
+            $s =~ s/"/""/smg;
+
+            $s = qq["$s"];
+        }
+
+        return join q[.], @id;
+    }
+    else {
+        $id =~ s/"/""/smg;
+
+        return qq["$id"];
+    }
 }
 
 sub _exec_sth ( $self, $query, @args ) {
@@ -622,15 +635,15 @@ sub attach ( $self, $name, $path = undef ) {
 ## |    3 | 126                  | Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_get_schema_patch_table_query'      |
 ## |      |                      | declared but not used                                                                                          |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 268                  | Subroutines::ProhibitExcessComplexity - Subroutine "do" with high complexity score (40)                        |
+## |    3 | 281                  | Subroutines::ProhibitExcessComplexity - Subroutine "do" with high complexity score (40)                        |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 351                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
+## |    3 | 364                  | Subroutines::ProtectPrivateSubs - Private subroutine/method used                                               |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    2 | 172                  | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 243, 315, 388        | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
+## |    2 | 256, 328, 401        | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 544                  | ControlStructures::ProhibitPostfixControls - Postfix control "while" used                                      |
+## |    2 | 557                  | ControlStructures::ProhibitPostfixControls - Postfix control "while" used                                      |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
